Simple Moscow Mule Recipe | Allrecipes
Description: Made with ginger beer, vodka, and lime juice, the refreshing taste of a Moscow mule cocktail can't be beat!

Advertisement

## Share options

##
Nutritional Information

### Simple Moscow Mule

Servings Per Recipe: 1
Calories: 191.7
% Daily Value *
protein: 0.2g 1 %
carbohydrates: 17.4g 6 %
dietary fiber: 0.7g 3 %
sugars: 14g
fat: 0.1g
vitamin a iu: 21.5IU
niacin equivalents: 0.1mg 1 %
vitamin c: 12.7mg 21 %
folate: 3.8mcg 1 %
calcium: 18mg 2 %
iron: 0.2mg 1 %
magnesium: 5.4mg 2 %
potassium: 49.7mg 1 %
sodium: 10.6mg
calories from fat: 0.6
*Percent Daily Values are based on a 2,000 calorie diet. Your daily values may be higher or lower depending on your calorie needs.
**Nutrient information is not available for all ingredients. Amount is based on available nutrient data.
(-)Information is not currently available for this nutrient. If you are following a medically restrictive diet, please consult your doctor or registered dietitian before preparing this recipe for personal consumption.

Powered by the ESHA Research Database © 2018,
ESHA Research, Inc. All Rights Reserved

## Recipe Reviews Photos

### Reviews for Photos of Simple Moscow Mule

Reviews: Most Helpful
Most Helpful
Most Positive
Least Positive
Newest
1 of 35
Arizona Desert Flower
Allstar
Rating: 5 stars
07/04/2014
We loved it! New summer favorite drink! We ended up finding Ginger Beer at Total Wine & more, Fry's didn't have it. Don't try and substitute it with ginger ale; ginger ale and ginger beer are separate things.
Helpful
(18)
foodelicious
Rating: 5 stars
04/27/2015
So refreshing! I used Jamaican ginger beer and domestic vodka instead of Russian, so what would you call that? I also threw a sprig of mint in there just for looks. Because presentation is everything. Thanks for the recipe!
Helpful
(8)
FrackFamily5 CA—>CT
Rating: 5 stars
07/11/2014
My favorite al time cocktail!! This was great! Just need a copper mug!
Helpful
(7)
Mother Ann
Rating: 5 stars
08/28/2016
I searched high and low for the perfect copper mug. So it only makes sense I would search for the perfect Moscow Mule recipe! I used Goslings Ginger Beer and vodka we got from a distillery we visited in Virginia this past summer. Fresh-squeezed lime juice is the only way to go. Yummy! So cool and refreshing on a hot summer day!
Helpful
(1)
AndreaY
Rating: 5 stars
05/26/2018
If you want a light easy drink that goes down smoothly you simply cannot go wrong with a Moscow mule. It is so delicious and takes seconds to make. I love this drink!
Helpful
(1)
Verrildd
Rating: 4 stars
06/29/2015
Delicious!
Helpful
(1)
reverie
Rating: 5 stars
08/10/2018
My new favorite drink that I first had on a cruise a few months back. So refreshing. Made this exactly as written with a slice of candied ginger on the glass. Yum.
Helpful
(1)
Alexa Leigh Caffrey
Rating: 5 stars
12/28/2015
perfect! I added a sprig of fresh mint as well. Used Bundaberg brand ginger beer--my favorite!:D
Helpful
(1)
Kathy L
Rating: 5 stars
02/03/2020
Make sure you use ginger beer, not ginger ale! A great summer drink, but also nice when you have a cold as the ginger is good on the throat.
Helpful
(1)
Simple Moscow Mule
1 of 13 Simple Moscow Mule
Crocketts
Simple Moscow Mule
2 of 13 Simple Moscow Mule
Arizona Desert Flower
Simple Moscow Mule
3 of 13 Simple Moscow Mule
ambedore81
Simple Moscow Mule
4 of 13 Simple Moscow Mule
vburrito
Simple Moscow Mule
5 of 13 Simple Moscow Mule
Buckwheat Queen
Simple Moscow Mule
6 of 13 Simple Moscow Mule
Bibi
Simple Moscow Mule
7 of 13 Simple Moscow Mule
Sebastian Nardo
Simple Moscow Mule
8 of 13 Simple Moscow Mule
foodelicious
Simple Moscow Mule
9 of 13 Simple Moscow Mule
MountainLovinGal
Simple Moscow Mule
10 of 13 Simple Moscow Mule
justin
Simple Moscow Mule
11 of 13 Simple Moscow Mule
Jami Rogers
Simple Moscow Mule
12 of 13 Simple Moscow Mule
Carly Polizzi
Simple Moscow Mule
13 of 13 Simple Moscow Mule
AndreaY

##
Review this recipe

Add Photo
Simple Moscow Mule
Rate this recipe Your rating Rate this a 1:
Couldn't eat it Rate this a 2:
Didn't like it Rate this a 3:
It was OK Rate this a 4:
Liked it Rate this a 5:
Loved it
What did you think about this recipe? Did you make any changes or notes?
Success!Thanks for adding your feedback.

## Successfull saved

Congrats! You saved Simple Moscow Mule to your Favorites

## Login

##

## View image

Simple Moscow Mule
this link is to an external site that may or may not meet accessibility guidelines.